import json
import jsonschema

DEFAULT_ORGANIZATIONS = [
    {
        "name": "GÉANT Staff",
        "excluded_nrens": [],
        "excluded_dashboards": []
    },
    {
        "name": "NRENs",
        "excluded_nrens": [],
        "excluded_dashboards": [
            "GÉANT Office devices",
            "GÉANT VM"
        ]
    },
    {
        "name": "General Public",
        "excluded_nrens": [
                "CARNET",
                "PSNC"
        ],
        "excluded_dashboards": [
            "GÉANT Office devices",
            "GÉANT VM"
        ]
    },
    {
        "name": "CAE1 - Europe",
        "excluded_nrens": [],
        "excluded_dashboards": [
            "GÉANT Office devices",
            "GÉANT VM"
        ]
    },
    {
        "name": "CAE1 - Asia",
        "excluded_nrens": [
                "CARNET",
                "PSNC"
        ],
        "excluded_dashboards": [
            "GÉANT Office devices",
            "GÉANT VM"
        ]
    }
]

CONFIG_SCHEMA = {
    "$schema": "http://json-schema.org/draft-07/schema#",

    "definitions": {
        "influx-datasource": {
            "type": "object",
            "properties": {
                    "name": {"type": "string"},
                    "username": {"type": "string"},
                    "password": {"type": "string"},
                    "type": {"type": "string"},
                    "url": {"type": "string"},
                    "database": {"type": "string"},
                    "basicAuth": {"type": "boolean"},
                    "access": {"type": "string"},
                    "isDefault": {"type": "boolean"},
                    "readOnly": {"type": "boolean"}
            },
            "required": [
                "name",
                "type",
                "url",
                "database",
                "basicAuth",
                "access",
                "isDefault",
                "readOnly"
            ]
        },
        "organization": {
            "type": "object",
            "properties": {
                    "name": {"type": "string"},
                    "excluded_nrens": {
                        "type": "array",
                        "items": {"type": "string"}
                    },
            },
            "required": [
                "name",
                "excluded_nrens",
            ]
        }
    },

    "type": "object",
    "properties": {
        "admin_username": {"type": "string"},
        "admin_password": {"type": "string"},
        "hostname": {"type": "string"},
        "listen_port": {"type": "integer"},
        "inventory_provider": {"type": "string"},
        "datasources": {
            "type": "object",
            "properties": {
                "influxdb": {"$ref": "#definitions/influx-datasource"}
            },
            "additionalProperties": False
        },
    },
    "required": [
        "admin_username",
        "admin_password",
        "hostname",
        "inventory_provider",
        "datasources"
    ]
}


def defaults():
    return {
        "admin_username": "admin",
        "admin_password": "admin",
        "hostname": "localhost:3000",
        "listen_port": 3001,
        "datasources": {}
    }


def load(f):
    """
    loads, validates and returns configuration parameters

    :param f: file-like object that produces the config file
    :return:
    """
    config = json.loads(f.read())
    jsonschema.validate(config, CONFIG_SCHEMA)
    return config
